@@ -7,8 +7,5 @@ pub type Result<T> = anyhow::Result<T, Error>;
 pub enum Error {
     /// Column and value vector having different length
     #[error("Columns and values length mismatch: {col_len} != {val_len}")]
-    ColValNumMismatch {
-        col_len: usize,
-        val_len: usize,
-    }
-}
\ No newline at end of file
+    ColValNumMismatch { col_len: usize, val_len: usize },
+}
