@@ -28,7 +28,9 @@ where
                     counter += 1;
                     i += 1;
                     continue;
-                } else if (mark.as_ref(), true) == query_builder.placeholder() && i + 1 < tokens.len() {
+                } else if (mark.as_ref(), true) == query_builder.placeholder()
+                    && i + 1 < tokens.len()
+                {
                     if let Token::Unquoted(next) = &tokens[i + 1] {
                         if let Ok(num) = next.parse::<usize>() {
                             output.push(query_builder.value_to_string(&params[num - 1]));
