@@ -24,6 +24,7 @@ pub enum ColumnType {
     Decimal(Option<(u32, u32)>),
     DateTime(Option<u32>),
     Timestamp(Option<u32>),
+    TimestampWithTimeZone(Option<u32>),
     Time(Option<u32>),
     Date,
     Binary(Option<u32>),
@@ -232,6 +233,18 @@ impl ColumnDef {
         self
     }
 
+    /// Set column type as timestamp with time zone. Postgres only
+    pub fn timestamp_with_time_zone(mut self) -> Self {
+        self.types = Some(ColumnType::TimestampWithTimeZone(None));
+        self
+    }
+
+    /// Set column type as timestamp with time zone plus custom precision
+    pub fn timestamp_with_time_zone_len(mut self, precision: u32) -> Self {
+        self.types = Some(ColumnType::TimestampWithTimeZone(Some(precision)));
+        self
+    }
+
     /// Set column type as time with custom precision
     pub fn time_len(mut self, precision: u32) -> Self {
         self.types = Some(ColumnType::Time(Some(precision)));
