@@ -477,7 +477,7 @@ fn select_33() {
 }
 
 #[test]
-fn select_34() {
+fn select_34a() {
     assert_eq!(
         Query::select()
             .column(Glyph::Aspect)
@@ -494,24 +494,47 @@ fn select_34() {
                     .gt(12)
                     .and(Expr::col(Glyph::Aspect).lt(18))
             )
-            .and_having(
-                Expr::col(Glyph::Aspect)
-                    .gt(22)
-                    .or(Expr::col(Glyph::Aspect).lt(28))
-            )
             .or_having(Expr::col(Glyph::Aspect).gt(32))
             .to_string(PostgresQueryBuilder),
         vec![
             r#"SELECT "aspect", MAX("image") FROM "glyph" GROUP BY "aspect""#,
             r#"HAVING (("aspect" > 2) OR ("aspect" < 8))"#,
             r#"OR (("aspect" > 12) AND ("aspect" < 18))"#,
-            r#"AND (("aspect" > 22) OR ("aspect" < 28))"#,
             r#"OR "aspect" > 32"#,
         ]
         .join(" ")
     );
 }
 
+#[test]
+#[should_panic]
+fn select_34b() {
+    assert_eq!(
+        Query::select()
+            .column(Glyph::Aspect)
+            .expr(Expr::col(Glyph::Image).max())
+            .from(Glyph::Table)
+            .group_by_columns(vec![Glyph::Aspect,])
+            .or_having(
+                Expr::col(Glyph::Aspect)
+                    .gt(2)
+                    .or(Expr::col(Glyph::Aspect).lt(8))
+            )
+            .and_having(
+                Expr::col(Glyph::Aspect)
+                    .gt(22)
+                    .or(Expr::col(Glyph::Aspect).lt(28))
+            )
+            .to_string(PostgresQueryBuilder),
+        vec![
+            r#"SELECT "aspect", MAX("image") FROM "glyph" GROUP BY "aspect""#,
+            r#"HAVING (("aspect" > 2) OR ("aspect" < 8))"#,
+            r#"AND (("aspect" > 22) OR ("aspect" < 28))"#,
+        ]
+        .join(" ")
+    );
+}
+
 #[test]
 fn select_35() {
     let (statement, values) = sea_query::Query::select()
